@@ -6,7 +6,7 @@ from djoser.conf import settings
 
 
 def encode_uid(pk):
-    return urlsafe_base64_encode(force_bytes(pk)).decode()
+    return force_text(urlsafe_base64_encode(force_bytes(pk)))
 
 
 def decode_uid(pk):
@@ -32,7 +32,7 @@ def logout_user(request):
 
 
 class ActionViewMixin(object):
-    def post(self, request):
+    def post(self, request, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
         return self._action(serializer)
